@@ -12,7 +12,7 @@ import shutil
 
 from tqdm import tqdm
 from shareloc_utils.smlm_file import read_smlm_file
-
+from shareloc_utils.formats import supported_text_formats
 
 class DownloadProgressBar(tqdm):
     def update_to(self, b=1, bsize=1, tsize=None):
@@ -32,18 +32,26 @@ def resolve_url(rdf_url, path):
     return urljoin(os.path.dirname(rdf_url) + "/", path)
 
 
-def convert_smlm(file_path, delimiter=",", extension=".csv"):
+def convert_smlm(file_path, delimiter=",", extension=".csv", format="ThunderSTORM (csv)"):
     smlm_info = read_smlm_file(file_path)
     converted_files = []
+    table_count = len(smlm_info["files"])
+    format_config = supported_text_formats[format];
+    header_transform = {}
+    for k, v in format_config["header_transform"].items():
+        header_transform[v]=k
+
     for tbi, file_info in enumerate(smlm_info["files"]):
         cols = file_info["cols"]
         rows = file_info["rows"]
         headers = file_info["headers"]
         table = file_info["data"]
-        fp = file_path.replace(".smlm", f".{tbi}{extension}")
+        fp = file_path.replace(
+            ".smlm", f".{tbi}{extension}" if table_count > 1 else extension
+        )
         with open(fp, "w") as f:
             for i in range(cols):
-                f.write(headers[i] + (delimiter if i < cols - 1 else "\n"))
+                f.write((header_transform.get(headers[i], headers[i])) + (delimiter if i < cols - 1 else "\n"))
             for i in tqdm(range(rows), total=rows):
                 for j in range(cols):
                     f.write(
@@ -60,6 +68,7 @@ def convert_potree(file_path, zip):
 
     manifest = read_smlm_file(file_path)
     tables = manifest["files"]
+    table_count = len(tables)
     converted_files = []
     for tbi, table in enumerate(tables):
         table = table["data"]
@@ -69,7 +78,9 @@ def convert_potree(file_path, zip):
         np.savetxt(".tmp.txt", xyz)
         BIN = os.path.dirname(pypotree.__file__) + "/bin"
 
-        name = os.path.basename(file_path.replace(".smlm", f".{tbi}"))
+        name = os.path.basename(
+            file_path.replace(".smlm", f".{tbi}" if table_count > 1 else "")
+        )
         output_dir = os.path.join(os.path.dirname(file_path), "potree")
         try:
             print(
@@ -83,7 +94,9 @@ def convert_potree(file_path, zip):
                 )
             )
             if zip:
-                zip_name = file_path.replace(".smlm", f".{tbi}.potree")
+                zip_name = file_path.replace(
+                    ".smlm", f".{tbi}.potree" if table_count > 1 else ".potree"
+                )
                 shutil.make_archive(
                     zip_name, "zip", os.path.join(output_dir, "pointclouds", name)
                 )
